@@ -14,9 +14,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-'''
+"""
 Senlin exception subclasses.
-'''
+"""
 
 import sys
 
@@ -24,7 +24,6 @@ from oslo_log import log as logging
 import six
 
 from senlin.common.i18n import _
-from senlin.common.i18n import _LE
 
 _FATAL_EXCEPTION_FORMAT_ERRORS = False
 LOG = logging.getLogger(__name__)
@@ -51,9 +50,9 @@ class SenlinException(Exception):
             # exc_info = sys.exc_info()
             # if kwargs doesn't match a variable in the message
             # log the issue and the kwargs
-            LOG.exception(_LE('Exception in string format operation'))
+            LOG.exception('Exception in string format operation')
             for name, value in kwargs.items():
-                LOG.error("%s: %s" % (name, value))  # noqa
+                LOG.error("%s: %s", name, value)  # noqa
 
             if _FATAL_EXCEPTION_FORMAT_ERRORS:
                 raise
@@ -82,30 +81,26 @@ class Forbidden(SenlinException):
 
 
 class BadRequest(SenlinException):
-    msg_fmt = _("The request is malformed: %(msg)s.")
+    msg_fmt = _("%(msg)s.")
 
 
 class InvalidAPIVersionString(SenlinException):
-    msg_fmt = _("API Version String (%(version)s) is of invalid format. It "
+    msg_fmt = _("API Version String '%(version)s' is of invalid format. It "
                 "must be of format 'major.minor'.")
 
 
 class MethodVersionNotFound(SenlinException):
-    msg_fmt = _("API version %(version)s is not supported on this method.")
+    msg_fmt = _("API version '%(version)s' is not supported on this method.")
 
 
 class InvalidGlobalAPIVersion(SenlinException):
-    msg_fmt = _("Version %(req_ver)s is not supported by the API. Minimum is "
-                "%(min_ver)s and maximum is %(max_ver)s.")
+    msg_fmt = _("Version '%(req_ver)s' is not supported by the API. Minimum "
+                "is '%(min_ver)s' and maximum is '%(max_ver)s'.")
 
 
 class MultipleChoices(SenlinException):
-    msg_fmt = _("Multiple results found matching the query criteria %(arg)s. "
-                "Please be more specific.")
-
-
-class InvalidParameter(SenlinException):
-    msg_fmt = _("Invalid value '%(value)s' specified for '%(name)s'")
+    msg_fmt = _("Multiple results found matching the query criteria "
+                "'%(arg)s'. Please be more specific.")
 
 
 class ResourceNotFound(SenlinException):
@@ -115,7 +110,7 @@ class ResourceNotFound(SenlinException):
     'policy', 'receiver', 'webhook', 'profile_type', 'policy_type',
     'action', 'event' and so on.
     """
-    msg_fmt = _("The %(type)s (%(id)s) could not be found.")
+    msg_fmt = _("The %(type)s '%(id)s' could not be found.")
 
     @staticmethod
     def enhance_msg(enhance, ex):
@@ -130,11 +125,16 @@ class ResourceInUse(SenlinException):
     'policy', 'receiver', 'webhook', 'profile_type', 'policy_type',
     'action', 'event' and so on.
     """
-    msg_fmt = _("The %(type)s %(id)s cannot be deleted: %(reason)s.")
+    msg_fmt = _("The %(type)s '%(id)s' cannot be deleted: %(reason)s.")
 
 
-class ProfileTypeNotMatch(SenlinException):
-    msg_fmt = _("%(message)s")
+class ResourceIsLocked(SenlinException):
+    """Generic exception for resource in use.
+
+    The resource type here can be 'cluster', 'node'.
+    """
+    msg_fmt = _("%(action)s for %(type)s '%(id)s' cannot be completed "
+                "because it is already locked.")
 
 
 class ProfileNotSpecified(SenlinException):
@@ -154,19 +154,15 @@ class PolicyNotSpecified(SenlinException):
 
 
 class PolicyBindingNotFound(SenlinException):
-    msg_fmt = _("The policy (%(policy)s) is not found attached to the "
-                "specified cluster (%(identity)s).")
+    msg_fmt = _("The policy '%(policy)s' is not found attached to the "
+                "specified cluster '%(identity)s'.")
 
 
 class PolicyTypeConflict(SenlinException):
-    msg_fmt = _("The policy with type (%(policy_type)s) already exists.")
+    msg_fmt = _("The policy with type '%(policy_type)s' already exists.")
 
 
-class InvalidSchemaError(SenlinException):
-    msg_fmt = _("%(message)s")
-
-
-class SpecValidationFailed(SenlinException):
+class InvalidSpec(SenlinException):
     msg_fmt = _("%(message)s")
 
 
@@ -190,7 +186,23 @@ class RequestLimitExceeded(SenlinException):
 
 
 class ActionInProgress(SenlinException):
-    msg_fmt = _("The %(type)s %(id)s is in status %(status)s.")
+    msg_fmt = _("The %(type)s '%(id)s' is in status %(status)s.")
+
+
+class ActionConflict(SenlinException):
+    msg_fmt = _("The %(type)s action for target %(target)s conflicts with "
+                "the following action(s): %(actions)s")
+
+
+class ActionCooldown(SenlinException):
+    msg_fmt = _("The %(type)s action for cluster %(cluster)s cannot be "
+                "processed due to Policy %(policy_id)s cooldown still in "
+                "progress")
+
+
+class ActionImmutable(SenlinException):
+    msg_fmt = _("Action (%(id)s) is in status (%(actual)s) while expected "
+                "status must be one of (%(expected)s).")
 
 
 class NodeNotOrphan(SenlinException):
@@ -200,43 +212,53 @@ class NodeNotOrphan(SenlinException):
 class InternalError(SenlinException):
     """A base class for internal exceptions in senlin.
 
-    The internal exception classes which inherit from :class:`InternalError`
-    class should be translated to a user facing exception type if need to be
-    made user visible.
+    The internal exception classes which inherit from :class:`SenlinException`
+    class should be translated to a user facing exception type if they need to
+    be made user visible.
     """
     msg_fmt = _("%(message)s")
     message = _('Internal error happened')
 
     def __init__(self, **kwargs):
         self.code = kwargs.pop('code', 500)
-        self.message = kwargs.pop('message', self.message)
+        # If a "message" is not provided, or None or blank, use the default.
+        self.message = kwargs.pop('message', self.message) or self.message
         super(InternalError, self).__init__(
             code=self.code, message=self.message, **kwargs)
 
 
 class EResourceBusy(InternalError):
     # Internal exception, not to be exposed to end user.
-    msg_fmt = _("The %(type)s (%(id)s) is busy now.")
+    msg_fmt = _("The %(type)s '%(id)s' is busy now.")
 
 
 class TrustNotFound(InternalError):
     # Internal exception, not to be exposed to end user.
-    msg_fmt = _("The trust for trustor (%(trustor)s) could not be found.")
+    msg_fmt = _("The trust for trustor '%(trustor)s' could not be found.")
 
 
 class EResourceCreation(InternalError):
     # Used when creating resources in other services
+    def __init__(self, **kwargs):
+        self.resource_id = kwargs.pop('resource_id', None)
+        super(EResourceCreation, self).__init__(
+            resource_id=self.resource_id, **kwargs)
     msg_fmt = _("Failed in creating %(type)s: %(message)s.")
 
 
 class EResourceUpdate(InternalError):
     # Used when updating resources from other services
-    msg_fmt = _("Failed in updating %(type)s %(id)s: %(message)s.")
+    msg_fmt = _("Failed in updating %(type)s '%(id)s': %(message)s.")
 
 
 class EResourceDeletion(InternalError):
     # Used when deleting resources from other services
-    msg_fmt = _("Failed in deleting %(type)s %(id)s: %(message)s.")
+    msg_fmt = _("Failed in deleting %(type)s '%(id)s': %(message)s.")
+
+
+class EServerNotFound(InternalError):
+    # Used when deleting resources from other services
+    msg_fmt = _("Failed in found %(type)s '%(id)s': %(message)s.")
 
 
 class EResourceOperation(InternalError):
@@ -252,21 +274,25 @@ class EResourceOperation(InternalError):
     The message here can be message from class 'ResourceNotFound',
     'ResourceInUse' and so on, or developer can specified message.
     """
+    def __init__(self, **kwargs):
+        self.resource_id = kwargs.pop('resource_id', None)
+        super(EResourceOperation, self).__init__(
+            resource_id=self.resource_id, **kwargs)
     # Used when operating resources from other services
-    msg_fmt = _("Failed in %(op)s %(type)s %(id)s: %(message)s.")
+    msg_fmt = _("Failed in %(op)s %(type)s '%(id)s': %(message)s.")
+
+
+class ESchema(InternalError):
+    msg_fmt = _("%(message)s")
 
 
 class InvalidPlugin(InternalError):
     msg_fmt = _("%(message)s")
 
 
-class InvalidSpec(InternalError):
-    msg_fmt = _("%(message)s")
-
-
 class PolicyNotAttached(InternalError):
-    msg_fmt = _("The policy (%(policy)s) is not attached to the specified "
-                "cluster (%(cluster)s).")
+    msg_fmt = _("The policy '%(policy)s' is not attached to the specified "
+                "cluster '%(cluster)s'.")
 
 
 class HTTPExceptionDisguise(Exception):
